@@ -35,9 +35,9 @@ def fermat(n):
                 if x**n + y**n == z**n:
                     yield x, y, z
 
-print "SF", simple_func(10)
+print("SF %s" % simple_func(10))
 
 for i in fermat(2):
-    print i
+    print(i)
 
-print "FINISHED"
+print("FINISHED")
