@@ -109,6 +109,7 @@ Keys in breakpoints view:
 
     enter - edit breakpoint
     d - delete breakpoint
+    e - enable/disable breakpoint
 
 License:
 --------
@@ -603,7 +604,7 @@ class DebuggerUI(FrameVarInfoKeeper):
                 self.cmdline_edit_sigwrap,
                 ("fixed", 10, AttrMap(
                     urwid.Button("Clear", clear_cmdline_history),
-                    "button", "focused button"))
+                    "command line clear button", "command line focused button"))
                 ])
 
         self.cmdline_pile = urwid.Pile([
@@ -893,6 +894,17 @@ class DebuggerUI(FrameVarInfoKeeper):
                 else:
                     self.update_breakpoints()
 
+        def enable_disable_breakpoint(w, size, key):
+            bp_entry, pos = self.bp_list._w.get_focus()
+
+            if bp_entry is None:
+                return
+
+            bp = self._get_bp_list()[pos]
+            bp.enabled = not bp.enabled
+
+            self.update_breakpoints()
+
         def examine_breakpoint(w, size, key):
             bp_entry, pos = self.bp_list._w.get_focus()
 
@@ -967,6 +979,7 @@ class DebuggerUI(FrameVarInfoKeeper):
         self.bp_list.listen("enter", examine_breakpoint)
         self.bp_list.listen("d", delete_breakpoint)
         self.bp_list.listen("s", save_breakpoints)
+        self.bp_list.listen("e", enable_disable_breakpoint)
 
         self.bp_list.listen("[", partial(change_rhs_box, 'breakpoints', 2, -1))
         self.bp_list.listen("]", partial(change_rhs_box, 'breakpoints', 2, 1))
@@ -1329,17 +1342,66 @@ class DebuggerUI(FrameVarInfoKeeper):
 
             text = self.cmdline_edit.edit_text
             pos = self.cmdline_edit.edit_pos
-            chopped_text = text[:pos]
-            remainder_text = text[pos:]
 
-            completed_chopped_text = \
-                    Completer(cmdline_get_namespace()).complete(chopped_text, 0)
+            chopped_text = text[:pos]
+            suffix = text[pos:]
+
+            # stolen from readline in the Python interactive shell
+            delimiters = " \t\n`~!@#$%^&*()-=+[{]}\\|;:\'\",<>/?"
+
+            complete_start_index = max(
+                    chopped_text.rfind(delim_i)
+                    for delim_i in delimiters)
+
+            if complete_start_index == -1:
+                prefix = ""
+            else:
+                prefix = chopped_text[:complete_start_index+1]
+                chopped_text = chopped_text[complete_start_index+1:]
+
+            state = 0
+            chopped_completions = []
+            completer = Completer(cmdline_get_namespace())
+            while True:
+                completion = completer.complete(chopped_text, state)
+
+                if not isinstance(completion, str):
+                    break
+
+                chopped_completions.append(completion)
+                state += 1
+
+            def common_prefix(a, b):
+                for i, (a_i, b_i) in enumerate(zip(a, b)):
+                    if a_i != b_i:
+                        return a[:i]
+
+                return a[:max(len(a), len(b))]
+
+            common_compl_prefix = None
+            for completion in chopped_completions:
+                if common_compl_prefix is None:
+                    common_compl_prefix = completion
+                else:
+                    common_compl_prefix = common_prefix(
+                            common_compl_prefix, completion)
+
+            completed_chopped_text = common_compl_prefix
+
             if completed_chopped_text is None:
-                completed_chopped_text = chopped_text
+                return
+
+            if (
+                    len(completed_chopped_text) == len(chopped_text)
+                    and len(chopped_completions) > 1):
+                add_cmdline_content(
+                        "   ".join(chopped_completions),
+                        "command line output")
+                return
 
             self.cmdline_edit.edit_text = \
-                    completed_chopped_text+remainder_text
-            self.cmdline_edit.edit_pos = len(completed_chopped_text)
+                    prefix+completed_chopped_text+suffix
+            self.cmdline_edit.edit_pos = len(prefix) + len(completed_chopped_text)
 
         def cmdline_append_newline(w, size, key):
             self.cmdline_edit.insert_text("\n")
@@ -1857,7 +1919,7 @@ class DebuggerUI(FrameVarInfoKeeper):
                 self.message("Package 'pygments' not found. "
                         "Syntax highlighting disabled.")
 
-        WELCOME_LEVEL = "e018"
+        WELCOME_LEVEL = "e022"
         if CONFIG["seen_welcome"] < WELCOME_LEVEL:
             CONFIG["seen_welcome"] = WELCOME_LEVEL
             from pudb import VERSION
@@ -1874,8 +1936,14 @@ class DebuggerUI(FrameVarInfoKeeper):
                     "(invoked by hitting '?' after this message) should get you "
                     "on your way.\n"
 
+                    "\nChanges in version 2014.1:\n\n"
+                    "- Make prompt-on-quit optional (Mike Burr)\n"
+                    "- Make tab completion in the built-in shell saner\n"
+                    "- Fix handling of unicode source\n  (reported by Morten Nielsen and Buck Golemon)\n"
+
                     "\nChanges in version 2013.5.1:\n\n"
-                    "- Fix loading of saved breakpoint conditions (Antoine Dechaume)\n"
+                    "- Fix loading of saved breakpoint conditions "
+                    "(Antoine Dechaume)\n"
                     "- Fixes for built-in command line\n"
                     "- Theme updates\n"
 
